if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

( cd usr/lib ; rm -rf libaudcore.so )
( cd usr/lib ; ln -sf libaudcore.so.1.0.0 libaudcore.so )
( cd usr/lib ; rm -rf libaudgui.so )
( cd usr/lib ; ln -sf libaudgui.so.1.0.0 libaudgui.so )
( cd usr/lib ; rm -rf libaudclient.so )
( cd usr/lib ; ln -sf libaudclient.so.2.0.0 libaudclient.so )
( cd usr/lib ; rm -rf libaudtag.so )
( cd usr/lib ; ln -sf libaudtag.so.1.0.0 libaudtag.so )
( cd usr/lib ; rm -rf libaudclient.so.2 )
( cd usr/lib ; ln -sf libaudclient.so.2.0.0 libaudclient.so.2 )
( cd usr/lib ; rm -rf libaudgui.so.1 )
( cd usr/lib ; ln -sf libaudgui.so.1.0.0 libaudgui.so.1 )
( cd usr/lib ; rm -rf libaudcore.so.1 )
( cd usr/lib ; ln -sf libaudcore.so.1.0.0 libaudcore.so.1 )
( cd usr/lib ; rm -rf libaudtag.so.1 )
( cd usr/lib ; ln -sf libaudtag.so.1.0.0 libaudtag.so.1 )
( cd usr/bin ; rm -rf audacious )
( cd usr/bin ; ln -sf audacious2 audacious )
( cd usr/bin ; rm -rf audtool )
( cd usr/bin ; ln -sf audtool2 audtool )
( cd usr/share/icons/hicolor/48x48/apps ; rm -rf audacious.png )
( cd usr/share/icons/hicolor/48x48/apps ; ln -sf ../../../../pixmaps/audacious.png audacious.png )
( cd usr/share/icons/hicolor/scalable/apps ; rm -rf audacious.svg )
( cd usr/share/icons/hicolor/scalable/apps ; ln -sf ../../../../pixmaps/audacious.svg audacious.svg )
( cd usr/man/man1 ; rm -rf audacious.1.gz )
( cd usr/man/man1 ; ln -sf audacious2.1.gz audacious.1.gz )
( cd usr/man/man1 ; rm -rf audtool.1.gz )
( cd usr/man/man1 ; ln -sf audtool2.1.gz audtool.1.gz )
